@@ -20,12 +20,10 @@
 #define UTIL_H
 
 #include <glib.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
   
-char *aisleriot_util_get_display_filename (const char *filename);
-
 typedef void (*AisleriotHelpFunc) (GtkWindow *, const char *, gpointer);
 
 void aisleriot_util_set_help_func (AisleriotHelpFunc func,
@@ -33,10 +31,6 @@ void aisleriot_util_set_help_func (AisleriotHelpFunc func,
 
 void aisleriot_display_help (GtkWindow * parent, const char *game_file);
 
-void aisleriot_util_add_atk_relation (GtkWidget *widget,
-                                      GtkWidget *other,
-                                      AtkRelationType type);
-
 G_END_DECLS
 
 #endif /* !UTIL_H */
