@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 __author__ = 'Robert Ancell <bob27@users.sourceforge.net>'
 __license__ = 'GNU General Public License Version 2'
@@ -15,16 +16,9 @@ from gettext import gettext as _
 
 import gobject
 import gtk
-import gtk.glade
 import gtk.gdk
 import cairo
 import pango
-try:
-    import gnome, gnome.ui
-except ImportError:
-    haveGnomeSupport = False
-else:
-    haveGnomeSupport = True
 
 from glchess.defaults import *
 
@@ -42,8 +36,10 @@ import network
 # Mark all windows with our icon
 gtk.window_set_default_icon_name(ICON_NAME)
 
-def loadGladeFile(name, root = None):
-    return gtk.glade.XML(os.path.join(GLADE_DIR, name), root, domain = DOMAIN)
+def loadUIFile(name, root = None):
+    ui = gtk.Builder()
+    ui.add_from_file(os.path.join(UI_DIR, name))
+    return ui
 
 class GLibTimer(glchess.ui.Timer):
     """
@@ -155,78 +151,51 @@ class GLibTimer(glchess.ui.Timer):
 class GtkUI(glchess.ui.UI):
     """
     """
-    # The Gtk+ GUI
-    _gui               = None
-    
-    # The time stored for animation
-    __lastTime         = None
-    __animationTimer   = None
-    
-    # The Gtk+ list model of the available player types
-    __playerModel      = None
-
-    # The about dialog open
-    __aboutDialog      = None
-
-    # Dictionary of save game dialogs keyed by view
-    __saveGameDialogs  = None
-
-    __renderGL         = False
-    openGLInfoPrinted  = False
-
-    # TODO
-    __joinGameDialogs  = None
-    __networkGames     = None
-    
-    __defaultWhiteAI   = None
-    __defaultBlackAI   = None
-
-    __attentionCounter = 0
-
-    whiteTimeString    = '∞'
-    blackTimeString    = '∞'
-    
-    # The window width and height when unmaximised and not fullscreen
-    width              = None
-    height             = None
-    isFullscreen       = False
-    isMaximised        = False
-    
-    view               = None
 
     def __init__(self, feedback):
         """Constructor for a GTK+ glChess GUI"""
-        if haveGnomeSupport:
-            gnome.program_init('glchess', VERSION,
-                               properties={gnome.PARAM_APP_DATADIR: APP_DATA_DIR})
-
         self.feedback = feedback
         self._watches = {}
         self.__networkGames = {}
         self.newGameDialog = None
         self.loadGameDialog = None
+        self.__aboutDialog = None
         self.__saveGameDialogs = {}
         self.__joinGameDialogs = []
+
+        # The time stored for animation
+        self.__lastTime         = None
+        self.__animationTimer   = None
+    
+        self.__renderGL         = False
+        self.openGLInfoPrinted  = False
+
+        self.__attentionCounter = 0
+
+        self.whiteTimeString    = '∞'
+        self.blackTimeString    = '∞'
+    
+        # Theo window width and height when unmaximised and not fullscreen
+        self.width              = None
+        self.height             = None
+        self.isFullscreen       = False
+        self.isMaximised        = False
+    
+        self.view               = None
         
         # Set the message panel to the tooltip style
         # (copied from Gedit)
         # In Gtk+ 2.11+ (I think) tip_window is now private so skip if it's not there (bug #459740)
-        tooltip = gtk.Tooltips()
-        tooltip.force_window()
-        if hasattr(tooltip, 'tip_window') and tooltip.tip_window != None:
-            tooltip.tip_window.ensure_style()
-            self._tooltipStyle = tooltip.tip_window.get_style()
-        else:
-            self._tooltipStyle = None
+        w = gtk.Window(gtk.WINDOW_POPUP)
+        w.set_name('gtk-tooltip')
+        w.ensure_style()
+        self._tooltipStyle = w.get_style()
         self._tooltipWidgetsDrawn = {}
         
-        self._gui = loadGladeFile('glchess.glade')
-        self._gui.signal_autoconnect(self)
+        self._gui = loadUIFile('glchess.ui')
+        self._gui.connect_signals(self)
         
-        self.mainWindow = self._gui.get_widget('glchess_app')
-        
-        # Workaround as Glade 2 always overrides the system style for toolbars
-        self.__getWidget('toolbar').unset_style()
+        self.mainWindow = self._gui.get_object('glchess_app')
         
         # Create the model for the player types
         self.__playerModel = gtk.ListStore(str, str, str)
@@ -234,7 +203,7 @@ class GtkUI(glchess.ui.UI):
         # Translators: Player Type Combo: Player is human controlled
         self.__playerModel.set(iter, 0, '', 1, 'stock_person', 2, _('Human'))
         
-        self.__logWindow = log.LogWindow(self._gui.get_widget('log_notebook'))
+        self.__logWindow = log.LogWindow(self._gui.get_object('log_notebook'))
         
         # Make preferences dialog
         self.preferences = dialogs.GtkPreferencesDialog(self)
@@ -249,16 +218,12 @@ class GtkUI(glchess.ui.UI):
         cell = gtk.CellRendererText()
         combo.pack_start(cell, False)
         combo.add_attribute(cell, 'text', 2)
-
-        # Disble help support
-        if haveGnomeSupport:
-            self._gui.get_widget('menu_help').show()
         
         self._updateViewButtons()
         
         # Watch for config changes
         for key in ['show_toolbar', 'show_history', 'fullscreen',
-                    'show_3d', 'show_comments', 'show_numbering',
+                    'show_3d', 'show_3d_smooth', 'show_comments', 'show_numbering',
                     'show_move_hints',
                     'width', 'height',
                     'move_format', 'promotion_type', 'board_view',
@@ -326,10 +291,6 @@ class GtkUI(glchess.ui.UI):
         """
         iter = self.__playerModel.append()
         self.__playerModel.set(iter, 0, name, 1, 'stock_notebook', 2, name)
-        
-        # Get the human to play against this AI
-        if self.__defaultBlackAI is None:
-            self.__defaultBlackAI = name
 
     def setView(self, title, feedback, isPlayable = True):
         """Extends ui.UI"""
@@ -378,23 +339,26 @@ class GtkUI(glchess.ui.UI):
     def setTimers(self, whiteTime, blackTime):
         """
         """
+        # Translators: Game Timer Label: Indicates that game has no time limit
+        unlimitedTimeText = _('∞')
+        
         if whiteTime is None:
-            whiteString = '∞'
+            whiteString = unlimitedTimeText
         else:
             t = whiteTime[1]
             whiteString = '%i:%02i' % (t / 60, t % 60)
         if blackTime is None:
-            blackString = '∞'
+            blackString = unlimitedTimeText
         else:
             t = blackTime[1]
             blackString = '%i:%02i' % (t / 60, t % 60)
             
         if whiteString != self.whiteTimeString:
             self.whiteTimeString = whiteString
-            self._gui.get_widget('white_time_label').queue_draw()
+            self._gui.get_object('white_time_label').queue_draw()
         if blackString != self.blackTimeString:
             self.blackTimeString = blackString
-            self._gui.get_widget('black_time_label').queue_draw()
+            self._gui.get_object('black_time_label').queue_draw()
 
     def run(self):
         """Run the UI.
@@ -402,7 +366,7 @@ class GtkUI(glchess.ui.UI):
         This method will not return.
         """        
         # Load configuration
-        for name in ['show_toolbar', 'show_history', 'show_3d',
+        for name in ['show_toolbar', 'show_history', 'show_3d', 'show_3d_smooth',
                      'show_comments', 'show_numbering', 'show_move_hints',
                      'move_format', 'promotion_type', 'board_view', 'maximised',
                      'enable_networking']:
@@ -432,38 +396,24 @@ class GtkUI(glchess.ui.UI):
 
     def addNetworkDialog(self, feedback):
         """Extends glchess.ui.UI"""
-        # Create the dialog
-        dialog = network.GtkNetworkGameDialog(self, feedback, self.__playerModel)
-        self.__joinGameDialogs.append(dialog)
-        
-        # Add the detected games into the dialog
-        #for (game, name) in self.__networkGames.iteritems():
-        #    dialog.addNetworkGame(name, game)
-        
-        return dialog
+        self.__networkDialog = network.GtkNetworkGameDialog(self, feedback)
+        return self.__networkDialog
                                  
     def addNetworkGame(self, name, game):
         """Extends glchess.ui.UI"""
-        self.__networkGames[game] = name
-        
-        # Update the open dialogs
-        for dialog in self.__joinGameDialogs:
-            dialog.addNetworkGame(name, game)
+        self.__networkDialog.addNetworkGame(name, game)
 
     def removeNetworkGame(self, game):
         """Extends glchess.ui.UI"""
-        self.__networkGames.pop(game)
-
-        # Update the open dialogs
-        for dialog in self.__joinGameDialogs:
-            dialog.removeNetworkGame(game)
+        self.__networkDialog.removeNetworkGame(game)
             
     def requestSave(self, title):
         """Extends glchess.ui.UI"""
         dialog = gtk.MessageDialog(flags = gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
                                    type = gtk.MESSAGE_WARNING,
                                    message_format = title)
-        dialog.format_secondary_text("If you don't save the changes to this game will be permanently lost")
+        # Translators: Save Game Dialog: Notice that game needs saving
+        dialog.format_secondary_text(_("If you don't save the changes to this game will be permanently lost"))
         # Translators: Save Game Dialog: Discard game button
         dialog.add_button(_('Close _without saving'), gtk.RESPONSE_OK)
         dialog.add_button(gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT)
@@ -598,6 +548,11 @@ Please contact your system administrator to resolve these problems, until then y
             self.__renderGL = value
             self.__getWidget('menu_view_3d').set_active(value)
             self.view.viewWidget.setRenderGL(value)
+
+        elif name == 'show_3d_smooth':
+            if not chessview.haveGLAccumSupport:
+                value = False
+            self.view.feedback.showSmooth(value)
                 
         elif name == 'show_comments':
             self.view.setShowComments(value)
@@ -646,7 +601,7 @@ Please contact your system administrator to resolve these problems, until then y
         return animating
 
     def __getWidget(self, name):
-        widget = self._gui.get_widget(name)
+        widget = self._gui.get_object(name)
         assert(widget is not None), 'Unable to find widget: %s' % name
         return widget
 
@@ -691,7 +646,7 @@ Please contact your system administrator to resolve these problems, until then y
 
     def _on_show_logs_clicked(self, widget):
         """Gtk+ callback"""
-        window = self._gui.get_widget('log_window')
+        window = self._gui.get_object('log_window')
         if widget.get_active():
             window.present()
         else:
@@ -826,6 +781,10 @@ Please contact your system administrator to resolve these problems, until then y
         except KeyError:
             dialog = self.__saveGameDialogs[self.view] = dialogs.GtkSaveGameDialog(self, self.view, self.view.feedback.getFileName())
         dialog.window.present()
+        
+    def _on_undo_move_clicked(self, widget):
+        """Gtk+ callback"""
+        self.view.feedback.undo()
 
     def _on_resign_clicked(self, widget):
         """Gtk+ callback"""
@@ -840,8 +799,8 @@ Please contact your system administrator to resolve these problems, until then y
         title = _("Unable to claim draw")
         # Translators: Draw Dialog: Notify user why they cannot claim draw
         message = _("""You may claim a draw when:
-a) The board has been in the same state three times (Three fold repitition)
-b) Fifty moves have occured where no pawn has moved and no piece has been captured (50 move rule)""")
+a) The board has been in the same state three times (Three fold repetition)
+b) Fifty moves have occurred where no pawn has moved and no piece has been captured (50 move rule)""")
         
         dialog = gtk.MessageDialog(flags = gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
                                    type = gtk.MESSAGE_WARNING,
@@ -858,7 +817,7 @@ b) Fifty moves have occured where no pawn has moved and no piece has been captur
     def _on_help_clicked(self, widget):
         """Gtk+ callback"""
         try:
-            gnome.help_display('glchess')
+            gtk.show_uri(self.mainWindow.get_screen(), "ghelp:glchess", gtk.get_current_event_time())
         except gobject.GError, e:
             # TODO: This should be a pop-up dialog
             print _('Unable to display help: %s') % str(e)
@@ -913,7 +872,7 @@ b) Fifty moves have occured where no pawn has moved and no piece has been captur
         
     def _on_log_window_delete_event(self, widget, event):
         """Gtk+ callback"""
-        self._gui.get_widget('menu_view_logs').set_active(False)
+        self._gui.get_object('menu_view_logs').set_active(False)
         
         # Stop the event - the window will be closed by the menu event
         return True
@@ -934,11 +893,11 @@ b) Fifty moves have occured where no pawn has moved and no piece has been captur
         if event.changed_mask & gtk.gdk.WINDOW_STATE_FULLSCREEN:
             self.isFullscreen = event.new_window_state & gtk.gdk.WINDOW_STATE_FULLSCREEN != 0
             if self.isFullscreen:
-                self._gui.get_widget('menu_fullscreen').hide()
-                self._gui.get_widget('menu_leave_fullscreen').show()
+                self._gui.get_object('menu_fullscreen').hide()
+                self._gui.get_object('menu_leave_fullscreen').show()
             else:
-                self._gui.get_widget('menu_leave_fullscreen').hide()
-                self._gui.get_widget('menu_fullscreen').show()
+                self._gui.get_object('menu_leave_fullscreen').hide()
+                self._gui.get_object('menu_fullscreen').show()
 
     def _on_close_window(self, widget, event):
         """Gtk+ callback"""
