@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 __author__ = 'Robert Ancell <bob27@users.sourceforge.net>'
 __license__ = 'GNU General Public License Version 2'
 __copyright__ = 'Copyright 2005-2006  Robert Ancell'
@@ -20,50 +21,50 @@ class GameHistory:
     def getUnfinishedGame(self):
         """Get the last game that is unfinished.
         
-        Returns the (PGN game, fileName) or (None, None) if no unfinished games.
+        Returns the (PGN game, fileName, inHistory) or (None, None, False) if no unfinished games.
         """
         g = None
         fileName = None
+        inHistory = False
         try:
             f = file(UNFINISHED_FILE, 'r')
             lines = f.readlines()
             f.close()
 
-            lines.reverse()
             index = 0
-            for line in lines:
-                fileName = line.strip()
+            while len(lines) > 0:
+                fileName = lines[0].strip()
+
                 try:
                     p = chess.pgn.PGN(fileName, 1)
                 except chess.pgn.Error, e:
-                    print e.description
-                    continue
+                    print e.message
                 except IOError, e:
                     print e.strerror
-                    continue
                 else:
-                    g = p[0]
-                    break
-                index += 1
+                    result = p[0].getTag(chess.pgn.TAG_RESULT)
+                    if result == chess.pgn.RESULT_INCOMPLETE:
+                        g = p[0]
+                        inHistory = fileName.startswith(HISTORY_DIR)
+                        break
+                lines = lines[1:]
+
         except IOError, e:
             if e.errno != errno.ENOENT:
                 print e.errno
                 print 'Failed to read unfinished list'
-                return (None, None)
+                return (None, None, False)
             lines = []
-        else:
-            lines = lines[index:]
 
         # Write the list back
         try:
             f = file(UNFINISHED_FILE, 'w')
-            lines.reverse()
             f.writelines(lines)
             f.close()
         except IOError:
             print 'Failed to write unfinished list'
 
-        return (g, fileName)
+        return (g, fileName, inHistory)
 
     def load(self, date):
         return
@@ -93,6 +94,28 @@ class GameHistory:
         
         return fileName
     
+    def rename(self, oldName, newName):
+        try:
+            os.unlink(oldName)
+        except OSError:
+            print 'Failed to remove game from history'
+
+        try:
+            f = file(UNFINISHED_FILE, 'r')
+            lines = f.readlines()
+            f.close()
+            
+            f = file(UNFINISHED_FILE, 'w')
+            for line in lines:
+                l = line.strip()
+                if l == oldName:
+                    f.write(newName + '\n')
+                else:
+                    f.write(l + '\n')
+            f.close()
+        except IOError:
+            print 'Failed to update unfinished list'
+    
     def save(self, g, fileName):
         """Save a game in the history.
         
@@ -125,13 +148,13 @@ class GameHistory:
             f.close()
             
             f = file(UNFINISHED_FILE, 'w')
-            for line in lines:
-                l = line.strip()
-                if l == fileName and result != chess.pgn.RESULT_INCOMPLETE:
-                    continue
-                f.write(l + '\n')
             if result == chess.pgn.RESULT_INCOMPLETE:
                 f.write(fileName + '\n')
+            for line in lines:
+                l = line.strip()
+                if l == fileName and result == chess.pgn.RESULT_INCOMPLETE:
+                    continue
+                f.write(l + '\n')
             f.close()
         except IOError:
             print 'Failed to update unfinished list'
