@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from OpenGL.GL import *
 from OpenGL.GLU import *
 import png
@@ -6,21 +7,6 @@ import array
 class Texture:
     """
     """
-    # Texture data
-    __data   = None
-    __format = GL_RGB
-    __width  = None
-    __height = None
-    
-    # Material properties
-    __ambient   = None
-    __diffuse   = None
-    __specular  = None
-    __emission  = None
-    __shininess = None
-
-    # OpenGL texture ID
-    __texture = None
     
     def __init__(self, fileName,
                  ambient  = (0.2, 0.2, 0.2, 1.0),
@@ -40,6 +26,16 @@ class Texture:
         self.__specular = specular
         self.__emission = emission
         self.__shininess = shininess
+
+        # Texture data
+        self.__data   = None
+        self.__format = GL_RGB
+        self.__width  = None
+        self.__height = None
+
+        # OpenGL texture ID
+        self.__texture = None
+
         try:
             self.__loadPIL(fileName)
         except ImportError:
@@ -48,11 +44,17 @@ class Texture:
     def __loadPNG(self, fileName):
         """
         """
-        reader = png.Reader(fileName)
+        try:
+            reader = png.Reader(fileName)
+        except IOError, e:
+            print 'Error loading texture file: %s: %s' % (fileName, e.strerror)
+            self.__data = None
+            return
+
         try:
             (width, height, data, metaData) = reader.read()
         except png.Error, e:
-            print 'Error loading texture %s: %s' % (fileName, e.message)
+            print 'Error parsing PNG file %s: %s' % (fileName, e.message)
             self.__data = None
             return
         
@@ -71,7 +73,12 @@ class Texture:
         import Image
         
         # Load the image file
-        image = Image.open(fileName)
+        try:
+            image = Image.open(fileName)
+        except IOError, e:
+            print 'Error loading texture file: %s: %s' % (fileName, e.strerror)
+            self.__data = None
+            return            
 
         # Crop the image so it has height/width a multiple of 2
         width = image.size[0]
@@ -117,7 +124,7 @@ class Texture:
                          self.__width,     # Width
                          self.__height,    # Height
                          0,                # Border
-                         GL_RGB,           # Format
+                         self.__format,    # Format
                          GL_UNSIGNED_BYTE, # Type
                          self.__data)
         
@@ -131,7 +138,7 @@ class Texture:
         if self.__texture is None:
             self.__texture = self.__generate()
             self.__data = None
-        
+
         # Use texture
         glBindTexture(GL_TEXTURE_2D, self.__texture)
         
