@@ -20,11 +20,15 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+
 #include <stdlib.h>
 #include <math.h>
-#include <games-scores.h>
-#include <games-scores-dialog.h>
+
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+
+#include <libgames-support/games-scores.h>
+#include <libgames-support/games-scores-dialog.h>
 
 #include "gbdefs.h"
 #include "gameconfig.h"
@@ -113,7 +117,7 @@ message_box (gchar * msg)
   GtkWidget *box;
 
   box = gtk_message_dialog_new (GTK_WINDOW (app), GTK_DIALOG_MODAL,
-				GTK_MESSAGE_INFO, GTK_BUTTONS_OK, msg);
+				GTK_MESSAGE_INFO, GTK_BUTTONS_OK, "%s", msg);
   gtk_dialog_run (GTK_DIALOG (box));
   gtk_widget_destroy (box);
 }
@@ -163,17 +167,20 @@ show_scores (gint pos, gboolean endofgame)
       gtk_window_present (GTK_WINDOW (scoresdialog));
     } else {
       scoresdialog = games_scores_dialog_new (GTK_WINDOW (app), 
-					highscores, _("Klotski Scores"));
+					highscores, _("Robots Scores"));
       games_scores_dialog_set_category_description (GAMES_SCORES_DIALOG
 						    (scoresdialog),
 						    _("Map:"));
     }
 
     if (pos > 0) {
+      play_sound (SOUND_VICTORY);
+
       games_scores_dialog_set_hilight (GAMES_SCORES_DIALOG (scoresdialog),
 				       pos);
       message = g_strdup_printf ("<b>%s</b>\n\n%s",
 				 _("Congratulations!"),
+                                 pos == 1 ? _("Your score is the best!") :
 				 _("Your score has made the top ten."));
       games_scores_dialog_set_message (GAMES_SCORES_DIALOG (scoresdialog),
 				       message);
@@ -235,7 +242,6 @@ log_score (gint sc)
     pos = games_scores_add_score (highscores, score);
   }
   g_free (sbuf);
-  update_score_state ();
 
   return pos;
 }
@@ -511,18 +517,14 @@ update_arena (void)
       if ((temp_arena[i][j] == OBJECT_HEAP) &&
 	  (push_xpos == i) && (push_ypos == j)) {
 	if (arena[i][j] == OBJECT_ROBOT1) {
-	  if (properties_splats ()) {
-	    add_splat_bubble (i, j);
-	    play_sound (SOUND_SPLAT);
-	  }
+	  add_splat_bubble (i, j);
+	  play_sound (SOUND_SPLAT);
 	  push_xpos = push_ypos = -1;
 	  score += game_config ()->score_type1_splatted;
 	}
 	if (arena[i][j] == OBJECT_ROBOT2) {
-	  if (properties_splats ()) {
-	    add_splat_bubble (i, j);
-	    play_sound (SOUND_SPLAT);
-	  }
+	  add_splat_bubble (i, j);
+	  play_sound (SOUND_SPLAT);
 	  push_xpos = push_ypos = -1;
 	  score += game_config ()->score_type2_splatted;
 	}
@@ -533,7 +535,7 @@ update_arena (void)
       if (arena[i][j] == OBJECT_ROBOT1) {
 	num_robots1 += 1;
       } else if (arena[i][j] == OBJECT_ROBOT2) {
-	num_robots2 += 2;
+	num_robots2 += 1;
       }
     }
   }
@@ -611,12 +613,9 @@ timeout_cb (void *data)
     if (endlev_counter >= DEAD_DELAY) {
       if (score > 0) {
 	sp = log_score (score);
-	if (sp > 0) {
-	  play_sound (SOUND_VICTORY);
-          if (show_scores (sp, TRUE) == GTK_RESPONSE_REJECT) {
-            quit_game ();
-          }
-	}
+        if (show_scores (sp, TRUE) == GTK_RESPONSE_REJECT) {
+          quit_game ();
+        }
       }
       start_new_game ();
     }
@@ -671,7 +670,7 @@ init_game (void)
   create_game_timer ();
 
   g_signal_connect (GTK_OBJECT (app), "key_press_event",
-		    GTK_SIGNAL_FUNC (keyboard_cb), 0);
+		    G_CALLBACK (keyboard_cb), 0);
 
   start_new_game ();
 }
@@ -1273,20 +1272,10 @@ safe_teleport (void)
   gint xp, yp, ixp, iyp;
   gint i, j;
 
-  if (properties_super_safe_moves () && !safe_teleport_available ()) {
-    /* FIXME: This code is untested - in normal play you have to get to 
-     * about level 61. */
-    if (!safe_move_available ()) {
-      message_box (_
-		   ("You have run out of safe moves - the robots have won!"));
-      kill_player ();
-      return FALSE;
-    } else if (safe_teleports > 0) {
-      message_box (_("There are no safe locations to teleport to!!"));
-      return FALSE;
-    } else {
-      return random_teleport ();
-    }
+  if (!safe_teleport_available ()) {
+    message_box (_("There are no safe locations to teleport to!!"));
+    kill_player ();
+    return FALSE;
   }
 
   if (safe_teleports <= 0)
